==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
export let ScatterSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterSplineSeriesDescriptionMetadata.a == null) {
                ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(ScatterSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            ScatterSplineSeriesDescriptionMetadata.b(a);
            a.ad("ScatterSplineSeries", () => new ScatterSplineSeriesDescription());
            a.ac("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
        }
    }
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ScatterSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSplineSeriesDescription } from "./ScatterSplineSeriesDescription";
/**
 * @hidden
 */
export let ScatterSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterSplineSeriesDescriptionMetadata.a == null) {
                ScatterSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterSplineSeriesDescriptionMetadata.c(ScatterSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(ScatterSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            ScatterSplineSeriesDescriptionMetadata.b(a);
            a.ae("ScatterSplineSeries", () => new ScatterSplineSeriesDescription());
            a.ad("ScatterSplineSeries", ScatterSplineSeriesDescriptionMetadata.a);
        }
    }
    ScatterSplineSeriesDescriptionMetadata.$t = markType(ScatterSplineSeriesDescriptionMetadata, 'ScatterSplineSeriesDescriptionMetadata');
    ScatterSplineSeriesDescriptionMetadata.a = null;
    return ScatterSplineSeriesDescriptionMetadata;
})();
